This specification language was published, as part of a greater project, in

> Santos A, Cunha A, Macedo N. *Schema-guided Testing of Message-oriented Systems*. ENASE 2022.

You can find the paper [here](https://haslab.github.io/SAFER/enase22.pdf).

A preliminary version of this specification language, along with a practical application scenario, was published in

> Carvalho R, Cunha A, Macedo N, Santos A. *Verification of system-wide safety properties of ROS applications*.

You can find the paper [here](https://ras.papercept.net/proceedings/IROS20/1158.pdf).

If you use HPL as part of your work, please cite these papers.
Here are their BibTeX entries:

```bibtex
@inproceedings{SantosCM22,
  author = {Andr{\'{e}} Santos and Alcino Cunha and Nuno Macedo},
  title = {Schema-guided Testing of Message-oriented Systems},
  booktitle = {17th International Conference on Evaluation of Novel Approaches to Software Engineering, {ENASE} 2022},
  pages = {26--37},
  publisher = {{SCITEPRESS}},
  year = {2022},
  doi = {10.5220/0010976100003176},
}

@inproceedings{CarvalhoCMS20,
    author = {Renato Carvalho and Alcino Cunha and Nuno Macedo and Andr{\'{e}} Santos},
    title = {Verification of System-Wide Safety Properties of {ROS} Applications},
    booktitle = {{IEEE/RSJ} International Conference on Intelligent Robots and Systems ({IROS})},
    pages = {7249--7254},
    publisher = {{IEEE}},
    year = {2020},
    doi = {10.1109/IROS45743.2020.9341085},
}
```
